Manifest

Struct Manifest 

pub struct Manifest {
    pub package: ManifestPackage,
    pub lib: Option<ManifestLibTarget>,
    pub bin: Option<Vec<ManifestBinTarget>>,
    pub features: Option<HashMap<String, HashSet<String>>>,
    pub dependencies: Option<HashMap<String, ManifestDependency>>,
    pub docs_meta: Option<ManifestDocsRsMetadata>,
}
Package manifest.

It includes only fields that are necessary for locating and parsing readme and library documentation.

See https://doc.rust-lang.org/cargo/reference/manifest.html for more details.

Fields

package: ManifestPackage

Defines a package.

lib: Option<ManifestLibTarget>

Library target settings.

bin: Option<Vec<ManifestBinTarget>>

Binary target settings.

features: Option<HashMap<String, HashSet<String>>>

Conditional compilation features.

dependencies: Option<HashMap<String, ManifestDependency>>

Package library dependencies.

docs_meta: Option<ManifestDocsRsMetadata>

Metadata that customize docs.rs builds.

Implementations

Source

impl Manifest

pub fn from_name_and_version(name: String, version: String) -> Self

Creates simple manifest from package name and version.

pub fn from_cargo_toml_content(content: &str) -> Result<Self, TomlParseError>

Creates manifest from Cargo.toml file contents.

pub fn from_cargo_toml_path(path: &Path) -> Result<Self, TomlReadError>

Reads manifest from a specified file path.

pub fn from_package_path(path: &Path) -> Result<Self, TomlReadError>

Reads manifest from the Cargo.toml file in the specified package path.

pub fn relative_readme_path(&self, root: &Path) -> Option<&Path>

Returns package relative readme path.

pub fn default_readme_filename(root: &Path) -> Option<&'static Path>

Returns package relative default readme path.

pub fn is_lib_documented_by_default(&self) -> bool

Returns true if the package’s library is documented by default.

See https://doc.rust-lang.org/cargo/commands/cargo-doc.html for more details.

pub fn relative_lib_path(&self) -> &Path

Returns package relative library file path.

See https://doc.rust-lang.org/cargo/commands/cargo-doc.html for more details.

pub fn default_relative_bin_path(&self) -> &'static Path

Returns package relative default binary file path.

See https://doc.rust-lang.org/cargo/commands/cargo-doc.html for more details.

pub fn relative_bin_path(&self, name: &str) -> Result<PathBuf, BinPathError>

Returns package relative binary file path by the specified binary target name.

See https://doc.rust-lang.org/cargo/commands/cargo-doc.html for more details.

pub fn default_relative_target_path(&self) -> &Path

Returns package default library or binary target.

See https://doc.rust-lang.org/cargo/commands/cargo-doc.html for more details.

pub fn docs_rs_default_target(&self) -> &str

Returns package target used for docs.rs builds.

See https://docs.rs/about/metadata for more details.

pub fn default_features(&self) -> HashSet<&str>

Returns a default package features.

pub fn all_features(&self) -> HashSet<&str>

Returns all package features.

pub fn docs_rs_features(&self) -> HashSet<&str>

Returns package features used for docs.rs builds.

See https://docs.rs/about/metadata for more details.